@@ -2,35 +2,17 @@
 Mark jobs as completed.
 
 Check tasks in a job, and when all are complete mark the job as complete.
-
-Initial delay: rand(15 minutes)
-Periodic delay: 60 minutes
 """
 
 import argparse
 import asyncio
 import logging
-import random
-import time
-
-from tornado.ioloop import IOLoop
 
 from iceprod.client_auth import add_auth_to_argparse, create_rest_client
 
 logger = logging.getLogger('job_completion')
 
 
-def job_completion(module):
-    """
-    Initial entrypoint.
-
-    Args:
-        module (:py:class:`iceprod.server.modules.schedule`): schedule module
-    """
-    # initial delay
-    IOLoop.current().call_later(random.randint(10,60*10), run, module.rest_client)
-
-
 async def run(rest_client, debug=False):
     """
     Actual runtime / loop.
@@ -39,7 +21,6 @@ async def run(rest_client, debug=False):
         rest_client (:py:class:`iceprod.core.rest_client.Client`): rest client
         debug (bool): debug flag to propagate exceptions
     """
-    start_time = time.time()
     datasets = await rest_client.request('GET', '/dataset_summaries/status')
     dataset_ids = []
     if 'processing' in datasets:
@@ -75,11 +56,6 @@ async def run(rest_client, debug=False):
             if debug:
                 raise
 
-    # run again after 60 minute delay
-    stop_time = time.time()
-    delay = max(60*60 - (stop_time-start_time), 60*10)
-    IOLoop.current().call_later(delay, run, rest_client)
-
 
 def main():
     parser = argparse.ArgumentParser(description='run a scheduled task once')
